@@ -10,7 +10,7 @@ use URI::Escape 'uri_unescape';
 use Hash::Util::FieldHash::Compat 'fieldhash';
 use WWW::Scripter 0.022; # screen
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 # Attribute constants (array indices)
 sub mech() { 0 }
@@ -192,7 +192,7 @@ sub engine { shift->[benm] }
 package WWW::Scripter::Plugin::JavaScript::Guard;
 
 sub new { bless \(my $object = pop) }
-DESTROY { eval { ${$_[0]}->destroy } }
+DESTROY { local $@; eval { ${$_[0]}->destroy } }
 
 
 # ------------------ DOCS --------------------#
@@ -206,7 +206,7 @@ WWW::Scripter::Plugin::JavaScript - JavaScript plugin for WWW::Scripter
 
 =head1 VERSION
 
-Version 0.008 (alpha)
+Version 0.009 (alpha)
 
 =head1 SYNOPSIS
 
@@ -437,11 +437,12 @@ be removed some time before version 1.
 
 =head1 PREREQUISITES
 
-perl 5.8.3 or higher (5.8.4 or higher recommended)
+perl 5.8.4 or higher
 
 HTML::DOM 0.032 or higher
 
-JE 0.022 or later (when the SpiderMonkey binding is stable enough it will 
+JE 0.056 or later (if the SpiderMonkey binding even becomes stable enough
+it will 
 become optional)
 
 CSS::DOM
@@ -462,16 +463,21 @@ LWP 5.815 or higher
 There is currently no system in place for preventing pages from different
 sites from communicating with each other.
 
-To report bugs, please e-mail the author.
+To report bugs, please e-mail
+L<bug-WWW-Scripter-Plugin-JavaScript@rt.cpan.org/mailto:bug-WWW-Scripter-Plugin-JavaScript@rt.cpan.org>.
 
 =head1 AUTHOR & COPYRIGHT
 
-Copyright (C) 2009-11 Father Chrysostomos
+Copyright (C) 2009-16 Father Chrysostomos
 <C<< join '@', sprout => join '.', reverse org => 'cpan' >>E<gt>
 
 This program is free software; you may redistribute it and/or modify
 it under the same terms as perl.
 
+=head1 ACKNOWLEDGEMENTS
+
+Thanks to Oleg G for providing a bug fix.
+
 =head1 SEE ALSO
 
 =over 4
